#' @title C-score / concordance statistic
#'
#' @description This function computes the C-score / concordance statistic (usually to evaluate the fit of a binary logistic regression).
#'
#' @param cv.f A character vector or a factor with the binary response variable
#' @param preds.num A numeric vector providing the predictions (usually predicted probabilities or log odds from a binary logistic regression)
#'
#' @examples
#' set.seed(1)
#' cv.f <- factor(c(sample(letters[1:2], 200, replace=TRUE, prob=c(0.7, 0.3)), sample(letters[1:2], 200, replace=TRUE, prob=c(0.3, 0.7))))
#' preds.num <- c(runif(200, 0, 0.8), runif(200, 0.2, 1))
#' C.score(cv.f, preds.num) # 0.5771459
#'
#' @return A numeric vector with the C-score. (From that, Somer's Dxy could be computed as 2C-1.)
#'
#' @export
#'
#' @author Stefan Th. Gries (www: <https://www.stgries.info>, ORCID id: 0000-0002-6497-3958)

C.score <- function (cv.f, preds.num) {
   wilcox.rank.sum <- wilcox.test(preds.num ~ cv.f, correct=FALSE)$statistic
   unname("-"(1, wilcox.rank.sum / prod(table(cv.f))))
}
