#' @title Matthew's correlation coefficient
#'
#' @description This function computes Matthew's correlation coefficient (i.e., phi) for a 2-by-2 table of frequencies, namely a confusion matrix of observed vs. predicted levels.
#'
#' @param c.m A confusion matrix, i.e. a 2-by-2 table comparing observations against predictions
#' @param obs.cv.f A character vector or a factor with two unique values/levels that represents the observed data
#' @param pred.cv.f A character vector or a factor with two unique values/levels that represents the predicted data
#'
#' @examples
#' a.2by2.table <- matrix(c(30, 10, 20, 40), ncol=2); MCC(a.2by2.table) # 0.4082483
#' obs <- factor(rep(letters[1:2], c(40, 60)))
#' pred <- factor(rep(letters[c(1:2,1:2)], c(30, 10, 20, 40)))
#' MCC(obs.cv.f=obs, pred.cv.f=pred) # 0.4082483
#'
#' @return A numeric vector with Matthew's correlation coefficient
#'
#' @export
#'
#' @author Stefan Th. Gries (www: <https://www.stgries.info>, ORCID id: 0000-0002-6497-3958)

MCC <- function (c.m=NULL, obs.cv.f=NULL, pred.cv.f=NULL) {
   # is the input not a confusion matrix, then generate one
   if (is.null(c.m)) { c.m <- table(obs.cv.f, pred.cv.f) }
   stopifnot("&"(          # stop the execution of MCC unless
      all(dim(c.m)==2),          # c.m has 2 rows & 2 columns
      all(rownames(c.m)==colnames(c.m)))) # w/ the same names
   setNames(
      unname(sqrt(chisq.test(c.m, correct=FALSE)$stat / sum(c.m))),
      "MCC/phi")
}
