#' @title R-squareds for regressions
#'
#' @description This function computes R-squareds for linear models (`base::lm`), binary logistic regressions (`base::glm`, but not for `family=quasibinomial`), ordinal regression (`MASS::polr`), and multinomial regressions (`nnet::multinom`).
#'
#' @param some.model A regression model of the above types
#'
#' @examples
#' set.seed(1)
#' response <- factor(c(sample(letters[1:2], 200, replace=TRUE, prob=c(0.7, 0.3)), sample(letters[1:2], 200, replace=TRUE, prob=c(0.3, 0.7))))
#' predictor <- c(runif(200, 0, 0.8), runif(200, 0.2, 1))
#' some.model <- glm(response ~ predictor, family=binomial)
#' R2s(some.model)
#'
#' @return A numeric vector with the C-score. (From that, Somer's Dxy could be computed as 2C-1.)
#'
#' @export
#'
#' @author Stefan Th. Gries (www: <https://www.stgries.info>, ORCID id: 0000-0002-6497-3958)

R2s <- function (some.model) {
   # NagelkerkeR2 doesn't work for family=quasibinomial; see
   # <https://cran.r-project.org/web/packages/bbmle/vignettes/quasi.pdf>
   null.model <- update(some.model, ~ 1)
   n <- nrow(model.frame(some.model))

   if (class(some.model)[1]=="lm") {
      output <- setNames(
         "/"(deviance(null.model)-deviance(some.model), deviance(null.model)),
         "Multiple R-squared")
   } else {
      output <- setNames(
         c("/"(deviance(null.model)-deviance(some.model), deviance(null.model)),
           as.numeric("/"(
              1 - exp((-2*logLik(some.model) - -2*logLik(null.model))/n),
              1 - exp(2*logLik(null.model)/n)))),
         c("McFadden R-squared", "Nagelkerke R-squared"))
   }
   return(output)
}
