#' @title Cohen's kappa
#'
#' @description This function computes Cohen's kappa, its standard error, its confidence interval, and its p-value.
#'
#' @param nm A numeric matrix with integers in equally many rows and columns
#' @param ci A numeric vector providing the confidence level

#' @examples
#' cohens.kappa(matrix(c(31, 6, 10, 4, 29, 7, 2, 8, 3), ncol=3, dimnames=list(Doctor2=c("schiz", "bipol", "other"), Doctor1=c("schiz", "bipol", "other"))))
#'
#' @return A numeric vector with Cohen's kappa, its standard error, its confidence interval, and its p-value
#'
#' @export
#'
#' @author Stefan Th. Gries (www: <https://www.stgries.info>, ORCID id: 0000-0002-6497-3958)

cohens.kappa <- function (
   nm,
   ci=0.95) { # from Sheskin (2011:687-690)
   options(warn=-1)
   all <- sum(nm)
   observed <- sum(diag(nm))
   expected <- sum(diag(chisq.test(nm, correct=FALSE)$expected))
   options(warn=0)

   kappa <- "/"(
      observed-expected,
      all-expected) # same as ((observed-expected)/all)/(1-(expected/all))
   se <- sqrt("/"(
      observed * (all-observed),
      all * ((all-expected)^2)))
   z.score.4.ci <- qnorm((1-ci)/2, lower.tail=FALSE)
   se.of.sampling <- sqrt("/"(
      expected,
      (all*(all-expected))))
   setNames(
      c(kappa, se, kappa-se*z.score.4.ci, kappa+se*z.score.4.ci,
        2*pnorm(kappa/se.of.sampling, lower.tail=FALSE)),
      c("Cohen's kappa", "se", "lower", "upper", "p (2-tailed)"))
}
